@@ -4,11 +4,14 @@ from .orders.orders import Orders
 from .product_fees.product_fees import ProductFees
 from .sellers.sellers import Sellers
 from .reports.reports import Reports
-from .reports.reports_v2 import ReportsV2
+from .reports.reports import Reports as ReportsV2
+
 from .products.products import Products
 from .sales.sales import Sales
 from .catalog.catalog import Catalog
 from .feeds.feeds import Feeds
+from .feeds.feeds import Feeds as FeedsV2
+
 from .inventories.inventories import Inventories
 from .fulfillment_inbound.fulfillment_inbound import FulfillmentInbound
 from .upload.upload import Upload
@@ -16,6 +19,9 @@ from .messaging.messaging import Messaging
 from .merchant_fulfillment.merchant_fulfillment import MerchantFulfillment
 
 ##### DO NOT DELETE ########## INSERT IMPORT HERE #######
+from .listings_restrictions.listings_restrictions import ListingsRestrictions
+    
+
 
 from .messaging.messaging import Messaging
     
@@ -81,6 +87,10 @@ __all__ = [
     "FulfillmentInbound",
     "MerchantFulfillment",
     ##### DO NOT DELETE ########## INSERT TITLE HERE #######
+    "ListingsRestrictions",
+    
+    "Feeds",
+    "FeedsV2",
     "ReportsV2",
     
     "Messaging",
