@@ -1,7 +1,7 @@
 from .aws_sig_v4 import AWSSigV4
 from .base_client import BaseClient
 from .client import Client
-from .helpers import fill_query_params, sp_endpoint, create_md5
+from .helpers import fill_query_params, sp_endpoint, create_md5, nest_dict, _nest_dict_rec, deprecated
 from .marketplaces import Marketplaces
 from .exceptions import SellingApiException
 from .exceptions import SellingApiBadRequestException
@@ -14,15 +14,19 @@ from .schedules import Schedules
 from .report_status import ReportStatus
 from .sales_enum import FirstDayOfWeek, Granularity, BuyerType
 from .fulfillment_channel import FulfillmentChannel
-from .deprecated import deprecated
+
 from .notifications import NotificationType
 from .credential_provider import CredentialProvider, MissingCredentials
 from .ApiResponse import ApiResponse
 from .processing_status import ProcessingStatus
 from .reportTypes import ReportType
-from sp_api.auth import AccessTokenClient
+from sp_api.auth import AccessTokenClient, Credentials
+from sp_api.auth.exceptions import AuthorizationError
+from sp_api.base.inegibility_reasons import IneligibilityReasonList
 
 __all__ = [
+    'Credentials',
+    'AuthorizationError',
     'AccessTokenClient',
     'ReportType',
     'ProcessingStatus',
@@ -49,5 +53,8 @@ __all__ = [
     'deprecated',
     'NotificationType',
     'CredentialProvider',
-    'MissingCredentials'
+    'MissingCredentials',
+    'nest_dict',
+    '_nest_dict_rec',
+    'IneligibilityReasonList'
 ]
